/* overrides certain izug.basetheme styles */
.directory-tags {
    margin-left: 20px;   
}

.portaltype-seantis-dir-council-directory #content #directoryResultList .directoryResult:first-child {
    padding-top: 5px;
}

.portaltype-seantis-dir-council-directory #landingPageIntro {
    margin-top: -15px;   
}

.portaltype-seantis-dir-council-directory #landingPageText {
    width: 97%;   
}

.directory-tags span {
    background-color: #efefef;
    font-size: 10px;
    padding: 2px 4px;
    border-radius: 2px;
}

#content .directory-tags a {
    display: inline;
    padding: 0; 
    font-weight: normal;
    color: black;
}

.council-left-column {
    float: left;
    width: 50%;   
    margin-top: 15px;
}

.council-right-column {
    float: right;   
    margin-top: 15px;
}

.council-details .directoryInfoText {
    padding-left: 0 !important;
}

.council-details .directoryInfoImage {
    float: left !important;   
}

div.council-address {
    float: left;   
}

div.council-address ul {
    list-style: none;
}

ul.council-address li {
    line-height: 12px;   
}

div.council-information {
    padding-left: 18px;
    width: 400px;
}

/* council member directory detail */
.directory-tmi {
    padding: 0 0 6px 22px;
}

.directory-tmi .item-address {
    padding-bottom: 8px;
}

.directory-tmi * {
    color: #454545 !important;
}

.directoryResult .item-information p {
    padding-left: 0 !important;
}

/* Hide comittee in iZug */
.cat3-tag span {
    display: none;
}

/* council tag information block on items view */
.council-tags {
    float: right;
}

.council-tags h3 {
    padding-left: 14px;
    border-bottom: 1px solid #ddd;
    color: #454545;
    font-weight: normal;
}

.council-tag-pointer {
    float: left;
    width: 14px;  
}

.council-tag-pointee {
    float: left;
    max-width: 390px; 
}

.council-tags ul {
    list-style: none;
    margin-left: 0;   
}

.council-tags span {
    line-height: 16px;
    font-weight: bold;
}

.full-resolution-portrait {
    margin-top: 5px;
}

/* filter info on directory view */
#directoryInfo {
     margin-top: 10px;   
}

.portaltype-seantis-dir-council-directory .council-tags {
    margin: 10px 0 0 20px;
    width: 450px;   
}

.portaltype-seantis-dir-council-directory .council-tag-description {
    width: 450px   
}

/* category descriptions are hidden by default, enable them */
#formfield-form-widgets-cat1_descriptions,
#formfield-form-widgets-cat2_descriptions,
#formfield-form-widgets-cat3_descriptions,
#formfield-form-widgets-cat4_descriptions {
    display: block;
}