.directory-tags {
    margin: 0;  
}

.directory-filter-info {
    padding: 0 0 0 0;
    margin: 0 0 5px 0;
    display: block;
}

.directory-tags a span {
    background-color: white;   
    padding: 0 1px 0 0;
}

.directoryResult {
    margin-left: 5px;
}

.directoryInfoText {
    font-weight: bold;   
}

.council-tags {
   float: none;
   margin: 0 0 -15px 15px !important;
   padding: 0 !important;
   font-size: 12px;
   max-width: 500px;
}

.after-council-tags {
   clear: both;   
}

.council-tags h3 {
   margin: 0 0 5px 0 !important;
   padding: 0 !important;   
}

.council-tag-pointer {
   display: none;
}

.council-tag-pointee {
   float: none;
   margin-top: 10px;
}

.council-tags ul {
    padding: 0 !important;
    margin: 10px 0 10px 0 !important;
}

.council-tag-description-block {
    margin-top: 5px !important;  
    font-weight: normal; 
}

.council-address {
    float: none !important;
    clear: both !important; 
}

.council-address ul {
    margin: 15px 0 20px 15px !important;   
    padding: 0;
}

#content .council-details .directoryInfoImage {
    float: none !important;
    clear: both !important;
    margin: 0 0 0 15px;
}
/* additional directory item information */
.directory-tmi * {
    font-size: 10px;
    font-weight: normal;
    color: black !important;
    margin: 0;
}
.directory-tmi {
    padding: 10px 0 5px 0;
}